#
# spec file for package python-anywidget
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define distver 0.9.13
Name:           python-anywidget
Version:        0.9.13
Release:        1.1
Summary:        Custom jupyter widgets made easy
License:        MIT
URL:            https://github.com/manzt/anywidget
Source:         https://files.pythonhosted.org/packages/source/a/anywidget/anywidget-%{version}.tar.gz
BuildRequires:  %{python_module hatch-jupyter-builder}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  jupyter-rpm-macros
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module ipywidgets >= 7.6.0}
BuildRequires:  %{python_module msgspec}
BuildRequires:  %{python_module psygnal >= 0.8.1}
BuildRequires:  %{python_module pydantic}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typing-extensions >= 4.2.0}
BuildRequires:  %{python_module watchfiles}
# /SECTION
BuildRequires:  fdupes
Requires:       python-ipywidgets >= 7.6.0
Requires:       python-psygnal >= 0.8.1
Requires:       python-typing-extensions >= 4.2.0
Suggests:       python-comm >= 0.1.0
Suggests:       python-watchfiles >= 0.18.0
Provides:       python-anywidget = %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
Custom jupyter widgets made easy

- create widgets **without complicated cookiecutter templates**
- **publish to PyPI** like any other Python package
- prototype **within** `.ipynb` or `.py` files
- run in **Jupyter**, **JupyterLab**, **Google Colab**, **VSCode**, and more
- develop with **instant HMR**, like modern web frameworks

%package     -n jupyter-anywidget
Summary:        Custom jupyter widgets made easy
Requires:       jupyter-ipywidgets >= 7.0.0
Requires:       (jupyter-notebook or jupyter-nbclassic)
Requires:       python3dist(anywidget) >= %{distver}
Suggests:       python3-anywidget

%description -n jupyter-anywidget
- create widgets **without complicated cookiecutter templates**
- **publish to PyPI** like any other Python package
- prototype **within** `.ipynb` or `.py` files
- run in **Jupyter**, **JupyterLab**, **Google Colab**, **VSCode**, and more
- develop with **instant HMR**, like modern web frameworks

This package provides the jupyter notebook extensions.

%prep
%autosetup -p1 -n anywidget-%{version}
# Different layout in sdist than in repository
sed -i "s|../packages/anywidget/|../anywidget/labextension/|" tests/test_widget.py

%build
%pyproject_wheel

%install
%pyproject_install
%jupyter_move_config
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%fdupes %{buildroot}%{_jupyter_prefix}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/anywidget
%{python_sitelib}/anywidget-%{version}.dist-info

%files -n jupyter-anywidget
%doc README.md
%license LICENSE
%{_jupyter_prefix}/labextensions/anywidget
%{_jupyter_nbextension_dir}/anywidget
%_jupyter_config %{_jupyter_nb_notebook_confdir}/anywidget.json

%changelog
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.9.13
  * Improve legacy ESM deprecation notice with widget provenance
    and Python migration instruction (#609)
- Release 0.9.12
  * Add IPython Cell Magic for HMR (#594). New %%%%vfile cell magic
    for prototyping widgets in notebooks. Enables syntax
    highlighting and anywidget's Hot Module Replacement (HMR)
    directly within the notebook. Previously, front-end code had to
    be inline strings or file paths, causing loss of widget state
    when editing inline-strings in notebooks. The new %%%%vfile cell
    magic allows editing front-end code within the notebook with
    live reloading on cell re-execution. Use %%%%vfile <filename> to
    create a virtual file for either JavaScript or CSS, and use
    vfile:<filename> in _esm or _css attributes of an AnyWidget
    subclass to reference the virtual file. Anywidget applies HMR
    updates automatically on cell re-execution.
- Release 0.9.11
  * Relax version pinning for anywidget front end (#521)
  * Adopted ~major.minor.* notation for more flexible version
    compatibility in the front end, mirroring practices improve
    compatability in environments where bumping the front-end
    versions is not possible for end users (i.e., JupyterHub). This
    change is intended to enhance adaptability without causing
    disruptions. If issues arise, please report them on our issues
    page.
* Sun May  5 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.9.10
  * fix: Bring back anywidget.json to support notebook v6 discovery
    (#553)
- Releases 0.9.4 to 0.9.9
  * Make a blanket _repr_mimbundle_ implementation (#546)
  * experimental Ensure anywidget.experimental.command is called
    with self (#545)
  * experimental Replace invoke timeout with more flexible
    AbortSignal (#540)
  * Refactor AnyWidget command registration (#526)
  * feat: Suppress errors when inspecting widget for commands
    (#522)
  * Add experimental invoke API to call Python functions from the
    front end and (#453) await the response.
  * Bumped dependencies
* Thu Mar 28 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.9.3
  * Updated JS dependencies
- Release 0.9.2
  * Add Python 3.12 Support (#441)
  * feat(experimental): Add @dataclass decorator (#222)
  * Add error boundaries with nicer stack traces (#445)
- Release 0.9.1
  * refactor: Use signals for HMR runtime (#438)
- Drop anywidget-pr439-py312mock.patch
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19 (through
  ipywidgets)
* Sat Feb 10 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.9.0
  * Require ANYWIDGET_HMR to opt-in to HMR during development
  * Introduce front-end widget lifecycle methods (#395)
  * Deprecation Notice: Exporting a render from the front-end
    widget will trigger a deprecation notice in the browser
    console. The preferred way to define a widget's front-end code
    is now with a default object export.
  * These methods introduce lifecycle hooks for widget developers:
  - initialize: is executed once in the lifetime of a widget. It
    has access to the only the model to setup non-view event
    handlers or state to share across views.
  - render: is executed once per view, or for each notebook
    output cell. It has access to the model and a unique el DOM
    element. This method should be familiar and is used to setup
    event handlers or access state specific to that view.
  * Fix serialization of layout trait (#426)
- Add anywidget-pr439-py312mock.patch gh#manzt/anywidget#439
* Sun Jan 21 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.8.1
  * fix: Skip Promise serialization for ipywidget's layout/style
    traits (#412)
* Sat Dec 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.8.0
  * Remove re-export of @anywidget/vite from main package (#398)
  * Breaking change. If using our Vite plugin, please make sure to
    install @anywidget/vite (rather than importing from anywidget
    main package). This change allows us to version the Vite plugin
    and anywidget's core separately.
    // vite.config.mjs
    import { defineConfig } from "vite";
  - - import anywidget from "anywidget/vite";
    ++ import anywidget from "@anywidget/vite";
    If you are already using @anywidget/vite, there are no changes
    necessary.
* Sun Nov 26 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.7.1
  * feat: Raise Python error when file is missing (#345)
* Sat Oct 14 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.7.0
  * feat(experimental)!: Require include in _get_anywidget_state
    signature (#317)
  * Allows implementors to avoid re-serializing fields which aren't
    needed to send to the front end. This is a BREAKING change
    because it requires implementors of _get_anywidget_state to
    account for include in the function signature.
* Sat Sep 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.6.5
  * fix: disable auto-reloading in dist-packages (#276)
  * When the package is located in dist-packages, auto-reloading is
    now disabled. This prevents unnecessary warnings when the
    package is used in environments like Google Colab which are
    likely non-development installs.
- Release 0.6.4
  * fix: Keep support for binary traitlets (#274)
  * Uses structuredClone to ensure binary data is automatically
    serialized, correctly. Applies changes reverted in ipywidgets
    8.1.1.
* Mon Sep  4 2023 Steve Kowalik <steven.kowalik@suse.com>
- Initial release of 0.6.3.
